<?php
/**
 * Extends basic functionality for better Woocommerce compatibility
 *
 * @package Kava
 */

add_filter( 'kava_queried_object_id', 'kava_woo_set_shop_page' );

/**
 * Allow to rewrite shop page layout from page options
 *
 * @param  int $id Current page ID.
 *
 * @return int
 */
function kava_woo_set_shop_page( $id ) {

	if ( ! function_exists( 'is_shop' ) || ! function_exists( 'wc_get_page_id' ) ) {
		return $id;
	}

	if ( ! is_shop() && ! is_tax( 'product_cat' ) && ! is_tax( 'product_tag' ) ) {
		return $id;
	}

	$page_id = wc_get_page_id( 'shop' );

	return $page_id;
}


/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function kava_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}

add_action( 'after_setup_theme', 'kava_woocommerce_setup' );

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function kava_woocommerce_scripts() {
	wp_enqueue_style( 'kava-woocommerce-style', get_template_directory_uri() . '/assets/css/woocommerce.css' );

	$font_path   = WC()->plugin_url() . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

	wp_add_inline_style( 'kava-woocommerce-style', $inline_font );
}

add_action( 'wp_enqueue_scripts', 'kava_woocommerce_scripts' );

/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 *
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function kava_woocommerce_active_body_class( $classes ) {
	$classes[] = 'woocommerce-active';

	return $classes;
}

add_filter( 'body_class', 'kava_woocommerce_active_body_class' );

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 *
 * @return array $args related products args.
 */
function kava_woocommerce_related_products_args( $args ) {
	$defaults = array(
		'posts_per_page' => 3,
		'columns'        => 3,
	);

	$args = wp_parse_args( $defaults, $args );

	return $args;
}

add_filter( 'woocommerce_output_related_products_args', 'kava_woocommerce_related_products_args' );

/**
 * Remove default WooCommerce wrapper.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

if ( ! function_exists( 'kava_woocommerce_wrapper_before' ) ) {
	/**
	 * Before Content.
	 *
	 * Wraps all WooCommerce content in wrappers which match the theme markup.
	 *
	 * @return void
	 */
	function kava_woocommerce_wrapper_before() {
		?>
			<div <?php echo kava_get_site_content_wrapper_classes() ?>>
			<div class="row">
			<div id="primary" <?php kava_primary_content_class(); ?>>

			<main id="main" class="site-main">
		<?php
	}
}

add_action( 'woocommerce_before_main_content', 'kava_woocommerce_wrapper_before' );

if ( ! function_exists( 'kava_woocommerce_wrapper_after' ) ) {
	/**
	 * After Content.
	 *
	 * Closes the wrapping divs.
	 *
	 * @return void
	 */
function kava_woocommerce_wrapper_after() {
	?>
	</main><!-- #main -->
	</div><!-- #primary -->
	<?php
}
}
add_action( 'woocommerce_after_main_content', 'kava_woocommerce_wrapper_after' );


if ( ! function_exists( 'kava_woocommerce_sidebar_after' ) ) {
	/**
	 * Close tags after sidebar
	 */
	function kava_woocommerce_sidebar_after() {
		?>
			</div>
			</div>
		<?php
	}
}
add_action( 'woocommerce_sidebar', 'kava_woocommerce_sidebar_after', 99 );


/**
 * Sample implementation of the WooCommerce Mini Cart.
 *
 * You can add the WooCommerce Mini Cart to header.php like so ...
 *
 * <?php
 * if ( function_exists( 'kava_woocommerce_header_cart' ) ) {
 * kava_woocommerce_header_cart();
 * }
 * ?>
 */

if ( ! function_exists( 'kava_woocommerce_cart_link_fragment' ) ) {
	/**
	 * Cart Fragments.
	 *
	 * Ensure cart contents update when products are added to the cart via AJAX.
	 *
	 * @param array $fragments Fragments to refresh via AJAX.
	 *
	 * @return array Fragments to refresh via AJAX.
	 */
	function kava_woocommerce_cart_link_fragment( $fragments ) {
		ob_start();
		kava_woocommerce_cart_link();
		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;
	}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'kava_woocommerce_cart_link_fragment' );

if ( ! function_exists( 'kava_woocommerce_cart_link' ) ) {
	/**
	 * Cart Link.
	 *
	 * Displayed a link to the cart including the number of items present and the cart total.
	 *
	 * @return void
	 */
	function kava_woocommerce_cart_link() {
		?>
			<a class="header-cart__link" href="#" title="<?php esc_attr_e( 'View your shopping cart', 'kava' ); ?>">
		  <?php
		  $item_count_text = sprintf(
		  /* translators: number of items in the mini cart. */
			  esc_html__( '%d', 'kava' ),
			  WC()->cart->get_cart_contents_count()
		  );
		  ?>
				<i class="header-cart__link-icon"></i>
				<span class="header-cart__link-count"><?php echo esc_html( $item_count_text ); ?></span>
			</a>
		<?php
	}
}

if ( ! function_exists( 'kava_woocommerce_header_cart' ) ) {
	/**
	 * Display Header Cart.
	 *
	 * @return void
	 */
	function kava_woocommerce_header_cart() {
		if ( is_cart() ) {
			$class = 'current-menu-item';
		} else {
			$class = '';
		}
		?>
			<div class="header-cart">
				<div class="header-cart__link-wrap <?php echo esc_attr( $class ); ?>">
			<?php kava_woocommerce_cart_link(); ?>
				</div>
				<div class="header-cart__content">
			<?php
			$instance = array( 'title' => esc_html__( 'My cart', 'kava' ) );
			the_widget( 'WC_Widget_Cart', $instance );
			?>
				</div>
			</div>
		<?php
	}
}

add_action( 'kava-theme/top-panel/elements-right', 'kava_woocommerce_header_cart' );

if ( ! function_exists( 'kava_wc_loop_columns' ) ) {
	/**
	 * Change number or products per row
	 *
	 * @return int
	 */
	function kava_wc_loop_columns() {
		$sidebar_position = kava_theme()->customizer->get_value( 'blog_sidebar_position' );

		if ( 'fullwidth' === $sidebar_position ) {
			return 4;
		}

		return 3;
	}
}
add_filter( 'loop_shop_columns', 'kava_wc_loop_columns' );

/**
 * Remove woocommerce breadcrumbs
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

if ( ! function_exists( 'kava_get_wc_breadcrumbs' ) ) {

	/**
	 * Replace default breadcrumbs trail with WooCommerce-related.
	 *
	 * @param  bool $is_custom_breadcrumbs Default cutom breadcrumbs trigger.
	 * @param  array $args Breadcrumb arguments.
	 *
	 * @return bool|array
	 */
	function kava_get_wc_breadcrumbs( $is_custom_breadcrumbs, $args ) {

		if ( ! function_exists( 'is_woocommerce' ) || ! is_woocommerce() ) {
			return false;
		}

		if ( ! class_exists( 'Kava_Woo_Breadcrumbs' ) ) {
			require_once get_theme_file_path( 'inc/classes/class-woocommerce-breadcrumbs.php' );
		}

		$wc_breadcrumbs = new Kava_Woo_Breadcrumbs( kava_get_breadcrumbs_options() );

		return array( 'items' => $wc_breadcrumbs->items, 'page_title' => $wc_breadcrumbs->page_title );

	}

}
add_filter( 'cx_breadcrumbs/custom_trail', 'kava_get_wc_breadcrumbs', 10, 2 );

if ( ! function_exists( 'kava_wc_product_loop_start' ) ) {

	/**
	 * Rewrite loop start columns
	 *
	 * @param $ob_get_clean
	 *
	 * @return string
	 */
	function kava_wc_product_loop_start( $ob_get_clean ) {

		$context = wc_get_loop_prop( 'name' );
		$columns = array(
			'xs' => 1,
			'sm' => 2,
			'md' => 2,
			'lg' => wc_get_loop_prop( 'columns' ),
			'xl' => wc_get_loop_prop( 'columns' ),
		);

		switch ( $context ) {
		case 'related':
			$columns['xl'] = 4;
			$columns['lg'] = 4;
			break;
		case 'up-sells':
			$columns['xl'] = 4;
			$columns['lg'] = 4;
			break;
		case 'cross-sells':
			$columns['xl'] = 4;
			$columns['lg'] = 4;
			break;
		default:
			break;
	}

		$columns = apply_filters( 'kava-theme/woo/products_loop_columns', $columns );

		if ( is_shop() || is_product_taxonomy() || is_product() ) {
		$ob_get_clean = sprintf(
			'<ul class="products products-grid columns-xs-%1$s columns-sm-%2$s columns-md-%3$s columns-lg-%4$s columns-xl-%5$s">',
			esc_attr( $columns['xs'] ),
			esc_attr( $columns['sm'] ),
			esc_attr( $columns['md'] ),
			esc_attr( $columns['lg'] ),
			esc_attr( $columns['xl'] )
		);
	}

		$ob_get_clean = woocommerce_maybe_show_product_subcategories( $ob_get_clean );

		return $ob_get_clean;
	}

}
add_filter( 'woocommerce_product_loop_start', 'kava_wc_product_loop_start' );

if ( ! function_exists( 'kava_wc_pagination' ) ) {

	/**
	 * WooCommerce pagination
	 *
	 * @param $args
	 *
	 * @return mixed
	 */
	function kava_wc_pagination( $args ) {
		$args['prev_text'] = sprintf( '
		<span class="screen-reader-text">%1$s</span>
		<span class="nav-icon icon-prev"></span>\' %1$s',
			esc_html__( 'Prev', 'zemez' ) );

		$args['next_text'] = sprintf( '
		<span class="screen-reader-text">%1$s</span>
		%1$s <span class="nav-icon icon-next"></span>',
			esc_html__( 'Next', 'zemez' ) );

		return $args;
	}

}
add_filter( 'woocommerce_pagination_args', 'kava_wc_pagination' );

if ( ! function_exists( 'kava_init_shop_properties' ) ) {

	/**
	 * Init shop properties
	 */
	function kava_init_shop_properties() {

		// Sidebar properties for archive product
		if ( ( is_shop() || is_product_taxonomy() ) && ! is_singular( 'product' ) ) {
			kava_theme()->sidebar_enabled  = true;
			kava_theme()->sidebar_position = 'one-left-sidebar';
		}

	}

}
add_action( 'wp_head', 'kava_init_shop_properties', 2 );


if ( ! function_exists( 'kava_set_wc_dynamic_css_options' ) ) {

	/**
	 * Add dynamic WooCommerce styles
	 *
	 * @param $options
	 *
	 * @return mixed
	 */
	function kava_set_wc_dynamic_css_options( $options ) {

		array_push( $options['css_files'], get_theme_file_path( 'assets/css/dynamic-woocommerce.css' ) );

		return $options;

	}

}
add_filter( 'kava-theme/dynamic_css/options', 'kava_set_wc_dynamic_css_options' );